<template>
	<view class="uni-page-modal-3202-view" :class="largeMode?'large-mode':''">
		<view class="v-content">
			<!-- 表头样式 -->
			<OIForm ref="refBaseForm" class="v-headStyle" :form="head_styledef.form" viewMode></OIForm>
			<view class="v-scroll-view">
				<view class="view-content" id="tabpanel">
					<view class="dv-panel dv-panel-bkcolor" v-for="(style,ii) in detail1StyleDefList" :key="ii"
						@click="onPanelClick(ii)" :id="'panel'+style.form.htmlobjId">
						<div class="dv-panel-input">
							<OIForm class="v-area dv-panel" :form="style.form" viewMode></OIForm>
						</div>
					</view>
				</view>
			</view>
			<view class="view-bottom">
				<view class="uni-padding-wrap" v-if="dropdownBtns.length>0">
					<view class="uni-btn-v">
						<a @tap="clickDropdownBtns">
							<text class="mobox-normal-more" />
						</a>
					</view>
				</view>
				<button type="default" @click="onButtonClicked(btn)" class="btn_add"
					:style="{width:90/buttons.length + '%'}" v-for="(btn,key) in buttons">{{btn.ShowName}}</button>
			</view>

		</view>
	</view>
</template>

<script>
	import {
		Base64
	} from '@/js/Base64.js';
	import classUtils from "@/js/utils.js"
	import {
		appGetInfo,
		dictGetInfo
	} from "@/api/mobox.js"
	import {
		getUIStyleInfo,
		runCustomEvent,
		dataObjQuery,
		dataObjDel
	} from "@/api/data.js"
	import dayjs from "dayjs";
	import OIForm from '@/components/oi-form/index.vue'
	import buttonClickMixin from '@/mixins/button-click.js';

	export default {
		mixins: [buttonClickMixin],
		components: {
			OIForm
		},
		data() {
			return {
				largeMode: getApp().globalData.largeMode || false,
				title: this.translateSys('add2'),
				param: {},
				styledef: {},
				head_styledef: {
					form: {
						items: []
					}
				},
				detail1_styledef: {},
				detail1StyleDefList: [],
				active_id: '',
				activeItem: {},
			};
		},
		computed: {
			enter_view_event() {
				return {
					id: this.param.Enter_View_Event?.id || "",
					name: this.param.Enter_View_Event?.name || "",
				};
			},
			exit_view_event() {
				return {
					id: this.param.Exit_View_Event?.id || "",
					name: this.param.Exit_View_Event?.name || "",
				};
			},
			buttons() {
				const btns = this.param.ViewPage_Button || [];
				const list = [];
				if (btns.length > 3) {
					for (let i = 2; i > -1; i--) {
						list.push(btns[i]);
					}
					return list;
				} else {
					return btns;
				}
			},
			dropdownBtns() {
				const btns = this.param.ViewPage_Button || [];
				const list = [];
				if (btns.length > 3) {
					for (let i = 3; i < btns.length; i++) {
						list.push(btns[i]);
					}
					return list;
				} else {
					return [];
				}
			},
		},
		onBackPress(e) {
			this.navigateBackEvent()
		},
		async onLoad(options) {
			console.log(options);
			uni.setNavigationBarTitle({
				title: options.titlename
			}); //设置顶部标题 
			this.title = options.titlename;
			this.param = JSON.parse(options.param);
			this.head_styledef = {
				form: {
					items: []
				}
			};
			this.detail1_styledef = {};
			this.detail1StyleDefList = [];
			this.active_id = '';
			this.activeItem = {};
			await this.Head_UIStyleGetInfo(this.param.ClsID, this.param.MasterView_Panel.id);
			await this.Detail1_UIstyleGetInfo(this.param.ClsID, this.param.ViewItem_Panel.id);
			const dataObj = options.dataObj ? JSON.parse(options.dataObj) : {};
			if (dataObj) {
				let attrs = [];
				let master_view = dataObj?.master_view;
				Object.keys(master_view).forEach((a) => {
					attrs.push({
						attr: a,
						value: master_view[a]
					});
				});
				attrs.forEach((attr) => {
					this.head_styledef.form.items.forEach((ele2) => {
						if (ele2.name != "Layout") {
							if (ele2.fieldId == attr.attr) {
								ele2.value = attr.value;
							}
						} else if (ele2.name == "Layout") {
							ele2.setting.colList.forEach((col) => {
								if (col) {
									if (col.fieldId == attr.attr) {
										col.value = attr.value;
									}
								}
							});
						}
					});
				});
				this.viewAceionContent(dataObj.page.list);
			}
			if (this.enter_view_event.id)
				this.enterAfterEvent(this.enter_view_event);

		},
		methods: {
			//
			setData: function(obj) {
				let that = this;
				let keys = [];
				let val, data;

				Object.keys(obj).forEach(function(key) {
					keys = key.split(".");
					val = obj[key];
					data = that.$data;
					keys.forEach(function(key2, index) {
						if (index + 1 == keys.length) {
							that.$set(data, key2, val);
						} else {
							if (!data[key2]) {
								that.$set(data, key2, {});
							}
						}
						data = data[key2];
					});
				});
			},
			async Head_UIStyleGetInfo(class_id, style_id) { //获取自定义表单样式
				try {
					var $this = this;
					var dataInfo = {
						class_id: class_id,
						ui_style_id: style_id,
					};
					// console.log(dataInfo);
					const result = await getUIStyleInfo(dataInfo)
					var styledef = "";
					if (result.style_def) {
						//mobox2的style_def是json字符串
						styledef = result.style_def.replace(/\\/g, "");
						//mobox3的style_def是base64字符串
						if (!result.style_def.includes('"')) styledef = Base64.decode(result
							.style_def);
					}
					$this.head_styledef = result.style_def ? JSON.parse(styledef) : {};
					// this.form = this.head_styledef.form.model;
					// console.log($this.head_styledef);
					if ($this.head_styledef.form?.items) {
						$this.head_styledef.form.items.forEach(async (ele, index) => {
							if (ele.useDict == true) { //判断useDict是否使用字典
								await this.DictGetInfo(ele.bind.dict, index, 'mast');
							} else {
								if (ele?.name === "Select") {
									const selections = ele?.selections || []
									//有默认值，显示默认值
									let itemName = ele.value || "";
									if (itemName) {
										$this.head_styledef.form
											.model[ele.fieldId] = itemName;
									}
									$this.head_styledef.form.items[index].selections = selections.map((
										a) => {
										return {
											value: a.value,
											text: a.label
										}
									})
								}

							}

						});

					}
				} catch (ex) {
					// console.log(ex);
					let tip = typeof ex.errMsg == "string" ? ex.errMsg : ex
					uni.showModal({
						title: this.translateSys("error") + "1.1",
						content: tip,
						showCancel: false,
						confirmText: this.translateSys('close')
					});
				}

			},
			async Detail1_UIstyleGetInfo(class_id, style_id) { //获取自定义表单样式
				try {
					var $this = this;
					var dataInfo = {
						class_id: class_id,
						ui_style_id: style_id,
					};
					// console.log(dataInfo);
					const result = await getUIStyleInfo(dataInfo)
					var styledef = "";
					if (result.style_def) {
						//mobox2的style_def是json字符串
						styledef = result.style_def.replace(/\\/g, "");
						//mobox3的style_def是base64字符串
						if (!result.style_def.includes('"')) styledef = Base64.decode(result
							.style_def);
					}
					$this.detail1_styledef = result.style_def ? JSON.parse(styledef) : {};
					$this.detail1_styledef.SelBut_Checked = false;
				} catch (ex) {
					// console.log(ex);
					let tip = typeof ex.errMsg == "string" ? ex.errMsg : ex
					uni.showModal({
						title: this.translateSys("error") + "1.1",
						content: tip,
						showCancel: false,
						confirmText: this.translateSys('close')
					});
				}


			},
			async DictGetInfo(dict, index, type) { //Mobox3得到得到字典信息字典项列表
				this.data = [];
				var $this = this;
				var dataInfo = {
					dict_id: dict.id,
					dict_name: dict.name
				};
				try {
					const result = await dictGetInfo(dataInfo)
					if (type == 'mast') {
						var list = [];
						var itemName = '';
						(result.dict_item_list || []).forEach((item) => {
							if (item.is_default == '1')
								itemName = item.name
							list.push({
								text: item.value ? item.value : item.name,
								value: item.name,
							});
						});
						//有默认值，显示默认值
						if (itemName) {
							$this.head_styledef.form.items[index].value = itemName;
							var attr = $this.head_styledef.form.items[index].fieldId;
							$this.head_styledef.form.model[attr] = itemName;
						}
						$this.head_styledef.form.items[index].dict = list;
						var head_styledef = JSON.parse(JSON.stringify($this.head_styledef));
						$this.head_styledef = [];
						$this.head_styledef = head_styledef;
					}
				} catch (ex) {
					// console.log(ex);
					uni.showModal({
						title: this.translateSys("error") + "3",
						content: ex.errMsg,
						showCancel: false,
						confirmText: this.translateSys('close')
					});
				}
			},
			viewAceionContent(list) {
				if (!Array.isArray(list)) {
					return;
				}
				let styleStr = JSON.stringify(this.detail1_styledef); //已码盘

				list.forEach((cont) => {
					let attrs = [];
					let detailStyle = JSON.parse(styleStr);
					Object.keys(cont).forEach((a) => {
						attrs.push({
							attr: a,
							value: cont[a]
						});
					});
					attrs.forEach((attr) => {
						detailStyle.form.items.forEach((ele) => {
							if (ele.name != "Layout") {
								if (ele.fieldId == attr.attr) ele.value = attr.value;
							} else if (ele.name == "Layout") {
								ele.setting.colList.forEach((col) => {
									if (col) {
										if (col.fieldId == attr.attr) col.value = attr
											.value;
									}
								});
							}
						});
					});
					this.detail1StyleDefList.push(detailStyle); //码盘中
				});
			},
			//点中表单
			onPanelClick(value) { //点击面板高亮显示
				// console.log(value);
				this.setData({
					activeItem: this.detail1StyleDefList[value]
				})

			},
			//页面进入后事件
			async enterAfterEvent(event) {
				try {
					let data_json = [];
					let jsonlist = [];
					let detailStyleList = this.detail1StyleDefList;
					detailStyleList.forEach((style) => {
						let detail_attr = {};
						style.form.items.forEach((item) => {
							if (item.name == "Layout") {
								item.setting.colList.forEach((cols) => {
									if (cols != null) detail_attr[cols.fieldId] = cols.value;
								});
							} else detail_attr[item.fieldId] = item.value;
						});
						jsonlist.push(detail_attr);
					});
					data_json = Base64.encode(JSON.stringify(jsonlist));

					let input_param = {};
					this.head_styledef.form.items.forEach((item) => {
						if (item.name == "Layout") {
							item.setting.colList.forEach((cols) => {
								if (cols != null) input_param[cols.fieldId] = cols.value;
							});
						} else input_param[item.fieldId] = item.value;
					});
					input_param = Base64.encode(JSON.stringify(input_param));
					this.runCustomEvent({
						ed_type: 0,
						start_transaction: true,
						class_id: this.param.ClsID,
						event_id: event.id,
						input_param,
						data_json,
					})

				} catch (ex) {
					this.showError(ex);
				}
			},


			//事件处理
			async runCustomEvent(dataInfo) {
				try {
					var $this = this;

					runCustomEvent(dataInfo).then(result => {
						console.log(result);

						if (result.ret != 0) {
							var tip = result.err_info ? typeof result
								.err_info ==
								'string' ?
								result
								.err_info : result.err_info.join(
									'<br/>') : '';
							if (result.ret == 801) {
								if (this.param.Only_Script_Error) {
									let pos = tip.indexOf("：");
									if (pos > -1) tip = tip.substring(
										pos + 1);
								}
								uni.showModal({
									title: this.translateSys(
										"tip"),
									content: tip,
									showCancel: false,
									confirmText: this
										.translateSys('close')
								});
							} else uni.showModal({
								title: this.translateSys(
									"tip"),
								content: tip + ',' + this
									.translateSys('tip') +
									':' +
									result.ret,
								showCancel: false,
								confirmText: this.translateSys(
									'close')
							});
							return false;
						} else {
							var tip = result.info ? typeof result
								.info == 'string' ? result
								.info : result
								.info.join('<br/>') : '';
							if (tip) uni.showModal({
								title: this.translateSys(
									"tip"),
								content: tip,
								showCancel: false,
								confirmText: this.translateSys(
									'close')
							});

							if (result.result_type == 0 && result.action) {
								result.action.forEach(item => {
									if (item.action_type == "goback_to_pre_page") { //返回上一页
										var value = item.value;
										uni.navigateBack({
											delta: 1, //返回层数，2则上上页
										});
									} else {
										uni.showModal({
											title: this
												.translateSys(
													"tip"
												),
											content: this
												.translateSys(
													"quotation_mark_left"
												) +
												item
												.action_type +
												this
												.translateSys(
													"quotation_mark_right"
												) +
												this
												.translate(
													"tip_action_unprocessed"
												),
											showCancel: false,
											confirmText: this
												.translateSys(
													'close'
												)
										});
									}
								});
							} else {
								if (result.info) {
									uni.showModal({
										title: this
											.translateSys(
												"tip"),
										content: result.info,
										showCancel: false,
										confirmText: this
											.translateSys(
												'close')
									});
								}
							}
						}
					}).catch(ex => {
						console.log(ex);
						uni.showModal({
							title: this.translateSys("error") +
								"9.1",
							content: ex.errMsg,
							showCancel: false,
							confirmText: this.translateSys(
								'close')
						});
					});
				} catch (ex) {
					var tip = typeof ex == "string" ? ex : ex.message;
					uni.showModal({
						title: this.translateSys("error") + "9.2",
						content: this.translate('execute_event_failed') +
							this.translateSys(
								"comma") +
							this.translate('reason') + this.translateSys(
								"colon") + tip,
						showCancel: false,
						confirmText: this.translateSys('close')
					});

				}
			},
			//点击按钮列表
			clickDropdownBtns() {
				var that = this
				var itemlist = [];
				this.dropdownBtns.forEach((btn) => {
					itemlist.push(btn.ShowName);
				});
				uni.showActionSheet({
					// title: '按钮列表',
					itemList: itemlist,
					success: (e) => {
						console.log(e.tapIndex);
						var btn = that.dropdownBtns[e.tapIndex];
						that.onButtonClicked(btn);
					}
				})
			},
			onButtonClicked(btn) {

				let enviroment = {
					button: "top",
					button_name: btn.ShowName,
					cls_id: btn.Cls_ID,
					function: "3202",
					master: {},
				};
				if (btn.FunCode == "TriggerEvent") {
					this.onTriggerEvent(btn, enviroment);
				} else {
					this.$Message.warning(this.$t("sys.unrealized"));
				}

			},
			async onTriggerEvent(btn, enviroment) {
				let data_json = [];
				let jsonlist = [];

				let detailStyleList = this.detail1StyleDefList;
				detailStyleList.forEach((style) => {
					let detail_attr = {};
					style.form.items.forEach((item) => {
						if (item.name == "Layout") {
							item.setting.colList.forEach((cols) => {
								if (cols != null) detail_attr[cols.fieldId] = cols.value;
							});
						} else detail_attr[item.fieldId] = item.value;
					});
					jsonlist.push(detail_attr);
				});
				data_json = Base64.encode(JSON.stringify(jsonlist));

				let input_param = {};
				this.head_styledef.form.items.forEach((item) => {
					if (item.name == "Layout") {
						item.setting.colList.forEach((cols) => {
							if (cols != null) input_param[cols.fieldId] = cols.value;
						});
					} else input_param[item.fieldId] = item.value;
				});
				input_param = Base64.encode(JSON.stringify(input_param));
				await this.runCustomEvent({
					ed_type: 0,
					start_transaction: true,
					class_id: btn.Cls_ID,
					event_id: btn.Event.ID,
					input_param,
					data_json,
				});
			},
			navigateBackEvent() {
				if (!this.exit_view_event.id)
					return
				let data_json = [];
				let jsonlist = [];
				let detailStyleList = this.detail1StyleDefList;
				detailStyleList.forEach((style) => {
					let detail_attr = {};
					style.form.items.forEach((item) => {
						if (item.name == "Layout") {
							item.setting.colList.forEach((cols) => {
								if (cols != null) detail_attr[cols.fieldId] = cols.value;
							});
						} else detail_attr[item.fieldId] = item.value;
					});
					jsonlist.push(detail_attr);
				});
				data_json = Base64.encode(JSON.stringify(jsonlist));

				let input_param = {};
				this.head_styledef.form.items.forEach((item) => {
					if (item.name == "Layout") {
						item.setting.colList.forEach((cols) => {
							if (cols != null) input_param[cols.fieldId] = cols.value;
						});
					} else input_param[item.fieldId] = item.value;
				});
				input_param = Base64.encode(JSON.stringify(input_param));
				const eventChannel = this.getOpenerEventChannel();

				eventChannel.emit('ExitViewEvent', {
					ed_type: 0,
					start_transaction: true,
					class_id: this.param.ClsID,
					event_id: this.exit_view_event.id,
					input_param,
					data_json,
				});
			},
			cancel(e) { //取消
				this.navigateBackEvent()
				uni.navigateBack({
					delta: 1, //返回层数，2则上上页
				});
			},
			/**
			 * 只支持["column1='A' or column2='B'", "column3='C' and column4='D'", "column5='E'"]这种格式
			 * {
			 *     "model": 0 / 1,
			 *     "condition":
			 *     [
			 *         [
			 *             { },
			 *             { },
			 *             { }
			 *         ],
			 *         [
			 *             { }
			 *         ],
			 *         [
			 *             { }
			 *         ]
			 *     ]
			 * }
			 */

			toWhereBase64String(list) {
				if (typeof list == 'string') list = [list]
				var sql = []
				var seps = [' not in', ' in', '<>', '!=', '<=', '>=', '<', '=',
					'>', ' like'
				]
				list.forEach(ls => {
					var where = ls.trim()
					if (where.startsWith('(') && where.endsWith(')'))
						where = where.replace(
							/^\(/,
							'').replace(
							/\)$/, '')
					if (where.toLowerCase().includes(' and ')) {
						// 二级and放在第一级数组中
						where.split(/ and /i).forEach(li => {
							var l = li.trim()
							if (l.startsWith('(') && l.endsWith(
									')')) l = l.replace(
								/^\(/,
								'').replace(
								/\)$/, '')
							var sep = ''
							for (var i = 0; i < seps.length; i++) {
								if (l.toLowerCase().includes(seps[
										i])) {
									sep = seps[i]
									break
								}
							}
							if (sep) {
								var values = l.split(new RegExp(
									sep, 'i'))
								var field = values[0]?.trim()
									.replace(/^\[/, '')
									.replace(
										/\]$/, '')
								var value = ''
								var op = sep.trim()

								if ([' in', ' not in'].includes(
										sep) && values[1]
									?.toLowerCase().includes(
										'select ') && values[1]
									?.toLowerCase()
									.includes(
										' from ')) {
									value = l.replace(field, '')
										.replace(
											/^\s*(in|not in)\s*/i,
											'').trim()
									if (value.startsWith('(') &&
										value.endsWith(')'))
										value = value
										.replace(/^\(/, '')
										.replace(/\)$/, '').trim()
								} else {
									value = values[1]?.trim()
										.replace(/^\'/, '')
										.replace(
											/\'$/, '')

									if (['in', 'not in'].includes(
											op)) {
										value = value.replace(
											/^\(/, '').replace(
											/\)$/,
											'')
										value = value.split(',')
											.map(v => v.trim()
												.replace(
													/^\'/, '')
												.replace(/\'$/, '')
											)
									}
								}
								sql.push([{
									field,
									value,
									op
								}])
							}
						})
					} else if (where.toLowerCase().includes(' or ')) {
						// 二级or放在第二级同一组数组中
						var s = []
						where.split(/ or /i).forEach(li => {
							var l = li.trim()
							if (l.startsWith('(') && l.endsWith(
									')')) l = l.replace(
								/^\(/,
								'').replace(
								/\)$/, '')
							var sep = ''
							for (var i = 0; i < seps.length; i++) {
								if (l.toLowerCase().includes(seps[
										i])) {
									sep = seps[i]
									break
								}
							}
							if (sep) {
								var values = l.split(new RegExp(
									sep, 'i'))
								var field = values[0]?.trim()
									.replace(/^\[/, '')
									.replace(
										/\]$/, '')
								var value = ''
								var op = sep.trim()

								if ([' in', ' not in'].includes(
										sep) && values[1]
									?.toLowerCase().includes(
										'select ') && values[1]
									?.toLowerCase()
									.includes(
										' from ')) {
									value = l.replace(field, '')
										.replace(
											/^\s*(in|not in)\s*/i,
											'').trim()
									if (value.startsWith('(') &&
										value.endsWith(')'))
										value = value
										.replace(/^\(/, '')
										.replace(/\)$/, '').trim()
								} else {
									value = values[1]?.trim()
										.replace(/^\'/, '')
										.replace(
											/\'$/, '')

									if (['in', 'not in'].includes(
											op)) {
										value = value.replace(
											/^\(/, '').replace(
											/\)$/,
											'')
										value = value.split(',')
											.map(v => v.trim()
												.replace(
													/^\'/, '')
												.replace(/\'$/, '')
											)
									}
								}
								sql.push([{
									field,
									value,
									op
								}])
							}
						})
						sql.push(s)
					} else {
						var li = where
						// 单一查询条件直接放在第一级数组中
						var l = li.trim()
						if (l.startsWith('(') && l.endsWith(')')) l = l
							.replace(/^\(/, '')
							.replace(
								/\)$/, '')
						var sep = ''
						for (var i = 0; i < seps.length; i++) {
							if (l.toLowerCase().includes(seps[i])) {
								sep = seps[i]
								break
							}
						}
						if (sep) {
							var values = l.split(new RegExp(sep, 'i'))
							var field = values[0]?.trim().replace(/^\[/,
								'').replace(/\]$/, '')
							var value = ''
							var op = sep.trim()

							if ([' in', ' not in'].includes(sep) && values[
									1]?.toLowerCase()
								.includes('select ') &&
								values[1]?.toLowerCase().includes(' from ')
							) {
								value = l.replace(field, '').replace(
										/^\s*(in|not in)\s*/i, '')
									.trim()
								if (value.startsWith('(') && value
									.endsWith(')')) value = value
									.replace(/^\(/, '')
									.replace(/\)$/, '').trim()
							} else {
								value = values[1]?.trim().replace(/^\'/,
									'').replace(/\'$/, '')

								if (['in', 'not in'].includes(op)) {
									value = value.replace(/^\(/, '')
										.replace(/\)$/, '')
									value = value.split(',').map(v => v
										.trim().replace(/^\'/,
											'')
										.replace(/\'$/,
											''))
								}
							}
							sql.push([{
								field,
								value,
								op
							}])
						}
					}
				})

				if (sql.length > 0)
					return Base64.encode(JSON.stringify({
						model: 1,
						condition: sql
					}))
				else
					return ''
			},
			translate(t) {
				if (typeof this.$t == "function") return this.$t(`page.${t}`)
				else return t;
			},
			translateSys(t) {
				if (typeof this.$t == "function") return this.$t(`sys.${t}`)
				else return t;
			},

		},
	};
</script>
<style lang="scss">
	.uni-page-modal-3202-view {
		display: flex;
		flex-direction: column;
		height: calc(100vh - 30rpx);
		padding: 15rpx 0;

		.v-headStyle {
			width: 95%;
		}

		.v-content {
			flex: 1;
			display: flex;
			width: 100%;
			flex-direction: column;
			min-height: 100px;
			overflow: hidden;
			/* border:0.1px solid red; */
		}

		.view-content {
			width: calc(100% - 30rpx);
			padding: 10rpx 10rpx 10rpx 20rpx;
			display: flex;
			margin-top: 10rpx;
			flex-direction: column;


		}

		.dv-panel-bkcolor {
			border: 1px solid #ccc;
			border-radius: 5px;
		}

		.dv-panel {
			padding: 10rpx 10rpx 0rpx 0px;
			border-radius: 12rpx;
			margin-bottom: 10rpx;
		}

		.dv-panel-input {
			vertical-align: middle;
			width: 100%;
			display: inline-block;
			text-align: left;
		}

		.uni-forms-item {
			padding-bottom: 5rpx;
			margin-bottom: 0;

			.uni-forms-item__label {
				height: 20px !important;
				padding: 0 10rpx 0 0 !important;
			}
		}

		.bk-active {
			background-color: #D6FCB2;
		}

		.uni-padding-wrap {
			margin-top: 20rpx;
			background-color: #98DAEA;
			width: 104rpx;
			height: 80rpx;
			text-align: center;
			border-radius: 54rpx;
			padding: 24rpx 0 0 0;
			float: right;
			display: inline-block;
		}

		.uni-padding-wrap a {
			font-size: 40rpx;
		}

		.input-disabled {
			background-color: #f3f3f3 !important;
		}

		.v-scroll-view {
			flex: 1;
			overflow: hidden;
			width: 98%;
		}

		.view-bottom {
			display: block;
			width: calc(100% - 30rpx);
			padding: 10rpx 15rpx 20rpx 15rpx;
			align-items: center;

			.btn_add {
				width: 45%;
				background: #27A6E1;
				border: none;
				color: #fff;
				font-size: 38rpx;
				float: left;
				display: inline-block;
			}

			.btn_disabled {
				background-color: #ddd;
				color: #888;
			}

			.btn_cancel {
				width: 45%;
				margin: 0 10rpx;
				background: #fff;
				border: none;
				//color: #000;
				font-size: 38rpx;
				float: right;
				display: inline-block;
			}

			.btn_cancel2 {
				width: 90%;
				margin: 0 10rpx;
				background: #fff;
				//	border: none;
				color: #000;
				font-size: 38rpx;
				float: right;
				display: inline-block;
			}

			.uni-padding-wrap {
				margin: 2rpx 0 0 10rpx;
				background-color: #98DAEA;
				width: 104rpx;
				height: 80rpx;
				text-align: center;
				border-radius: 54rpx;
				padding: 24rpx 0 0 0;
				float: right;
				display: inline-block;
			}

			.uni-padding-wrap a {
				font-size: 40rpx;
			}
		}




	}
</style>